@@ -1,26 +1,23 @@
 from abc import ABCMeta, abstractmethod
 
-from typing import Optional, Protocol, Sequence, List
-
-
-OpStr = Optional[str]
+from typing import Protocol, Sequence
 
 
 class SourceInterfaceProto(Protocol):
-    def get(self, key: str, path: OpStr) -> OpStr: ...
+    def get(self, key: str, path: str | None) -> str | None: ...
 
 
 class SourceInterface(SourceInterfaceProto, metaclass=ABCMeta):
     @abstractmethod
-    def get(self, key: str, path: OpStr = None) -> OpStr:
+    def get(self, key: str, path: str | None = None) -> str | None:
         pass
 
 
 class SourceList(SourceInterface):
-    def __init__(self, sources: Sequence[Optional[SourceInterface]]) -> None:
-        self._sources: List[SourceInterface] = list(filter(None, sources))
+    def __init__(self, sources: Sequence[SourceInterface | None]) -> None:
+        self._sources: list[SourceInterface] = list(filter(None, sources))
 
-    def get(self, key: str, path: OpStr = None) -> OpStr:
+    def get(self, key: str, path: str | None = None) -> str | None:
         for source in self._sources:
             if value := source.get(key, path):
                 return value
