@@ -1,6 +1,6 @@
 from argparse import Namespace
 
-from ..source import SourceInterface, OpStr
+from ..source import SourceInterface
 
 
 class CliArgsConfig(SourceInterface):
@@ -32,7 +32,7 @@ class CliArgsConfig(SourceInterface):
     def __init__(self, args: Namespace) -> None:
         self._data = args
 
-    def get(self, key: str, module: OpStr = None) -> OpStr:
+    def get(self, key: str, module: str | None = None) -> str | None:
         key = key.split('.')[-1]
 
         return getattr(self._data, key, None)
